@@ -1,7 +1,6 @@
 from pagetools.src.Page import Page
+from pagetools.src.utils import filesystem
 
-from pathlib import Path
-import glob
 from collections import Counter
 import string
 import json
@@ -32,14 +31,7 @@ def get_codec_cli(files, level, index, most_common, output, remove_whitespace, o
     codec = Counter()
     xpath = build_xpath(level, index)
 
-    collected_files = []
-    for file in files:
-        if Path(file).is_file():
-            collected_files.append(file)
-        else:
-            globbed_files = glob.glob(file)
-            for _file in globbed_files:
-                collected_files.append(_file)
+    collected_files = filesystem.parse_file_input(files)
 
     with click.progressbar(collected_files) as _files:
         for file in _files:
